plugin

package
v0.9.0-beta Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 15, 2019 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Package plugin for caching directories using given backends

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Author

type Author struct {
	Avatar string
	Email  string
	Name   string
}

Author stores information about current commit's author

type Build

type Build struct {
	Created  int64
	Deploy   string
	Event    string
	Finished int64
	Link     string
	Number   int
	Started  int64
	Status   string
}

Build stores information about current build

type Commit

type Commit struct {
	Author  Author
	Branch  string
	Link    string
	Message string
	Ref     string
	Remote  string
	Sha     string
}

Commit stores information about current commit

type Config

type Config struct {
	// Indicates the files ACL, which should be one
	// of the following:
	//     private
	//     public-read
	//     public-read-write
	//     authenticated-read
	//     bucket-owner-read
	//     bucket-owner-full-control
	ACL           string
	ArchiveFormat string
	Bucket        string
	CacheKey      string
	Debug         bool
	// if not "", enable server-side encryption
	// valid values are:
	//     AES256
	//     aws:kms
	Encryption string
	Endpoint   string
	Key        string
	Mount      []string
	// Use path style instead of domain style.
	// Should be true for minio and false for AWS
	PathStyle bool
	Rebuild   bool
	// us-east-1
	// us-west-1
	// us-west-2
	// eu-west-1
	// ap-southeast-1
	// ap-southeast-2
	// ap-northeast-1
	// sa-east-1
	Region  string
	Restore bool
	Secret  string
}

Config plugin-specific parameters and secrets

type Plugin

type Plugin struct {
	Build  Build
	Commit Commit
	Config Config
	Repo   Repo
}

Plugin stores metadata about current plugin

func (*Plugin) Exec

func (p *Plugin) Exec() error

Exec entry point of Plugin, where the magic happens

type Repo

type Repo struct {
	Avatar  string
	Branch  string
	Link    string
	Name    string
	Owner   string
	Private bool
	Trusted bool
}

Repo stores information about repository that is built

Jump to