cachekey

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2019 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Generate

func Generate(tmpl, mount string, data metadata.Metadata) (string, error)

Generate generates key from given template as parameter or fallbacks hash

func Hash

func Hash(parts ...string) (string, error)

Hash generates a key based on given strings (ie. filename paths and branch)

func ParseTemplate

func ParseTemplate(tmpl string) (*template.Template, error)

ParseTemplate parses and mounts helper functions to template engine

Types

This section is empty.

Jump to